@@ -38,7 +38,7 @@ func NewManager(cfg *config.Config, log logutils.Log) *Manager {
 // WithCustomLinters loads private linters that are specified in the golangci config file.
 func (m *Manager) WithCustomLinters() *Manager {
 	if m.log == nil {
-		m.log = report.NewLogWrapper(logutils.NewStderrLog(""), &report.Data{})
+		m.log = report.NewLogWrapper(logutils.NewStderrLog(logutils.DebugKeyEmpty), &report.Data{})
 	}
 	if m.cfg != nil {
 		for name, settings := range m.cfg.LintersSettings.Custom {
@@ -100,76 +100,180 @@ func enableLinterConfigs(lcs []*linter.Config, isEnabled func(lc *linter.Config)
 
 //nolint:funlen
 func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
-	var bidichkCfg *config.BiDiChkSettings
-	var cyclopCfg *config.Cyclop
-	var decorderCfg *config.DecorderSettings
-	var errchkjsonCfg *config.ErrChkJSONSettings
-	var errorlintCfg *config.ErrorLintSettings
-	var exhaustiveCfg *config.ExhaustiveSettings
-	var exhaustiveStructCfg *config.ExhaustiveStructSettings
-	var exhaustructCfg *config.ExhaustructSettings
-	var gciCfg *config.GciSettings
-	var goModDirectivesCfg *config.GoModDirectivesSettings
-	var goMndCfg *config.GoMndSettings
-	var gosecCfg *config.GoSecSettings
-	var gosimpleCfg *config.StaticCheckSettings
-	var govetCfg *config.GovetSettings
-	var grouperCfg *config.GrouperSettings
-	var ifshortCfg *config.IfshortSettings
-	var importAsCfg *config.ImportAsSettings
-	var ireturnCfg *config.IreturnSettings
-	var maintIdxCfg *config.MaintIdxSettings
-	var nilNilCfg *config.NilNilSettings
-	var nlreturnCfg *config.NlreturnSettings
-	var predeclaredCfg *config.PredeclaredSettings
-	var reviveCfg *config.ReviveSettings
-	var staticcheckCfg *config.StaticCheckSettings
-	var stylecheckCfg *config.StaticCheckSettings
-	var tagliatelleCfg *config.TagliatelleSettings
-	var tenvCfg *config.TenvSettings
-	var testpackageCfg *config.TestpackageSettings
-	var thelperCfg *config.ThelperSettings
-	var unusedCfg *config.StaticCheckSettings
-	var varnamelenCfg *config.VarnamelenSettings
-	var wrapcheckCfg *config.WrapcheckSettings
+	var (
+		asasalintCfg        *config.AsasalintSettings
+		bidichkCfg          *config.BiDiChkSettings
+		cyclopCfg           *config.Cyclop
+		decorderCfg         *config.DecorderSettings
+		depGuardCfg         *config.DepGuardSettings
+		dogsledCfg          *config.DogsledSettings
+		duplCfg             *config.DuplSettings
+		dupwordCfg          *config.DupWordSettings
+		errcheckCfg         *config.ErrcheckSettings
+		errchkjsonCfg       *config.ErrChkJSONSettings
+		errorlintCfg        *config.ErrorLintSettings
+		exhaustiveCfg       *config.ExhaustiveSettings
+		exhaustiveStructCfg *config.ExhaustiveStructSettings
+		exhaustructCfg      *config.ExhaustructSettings
+		forbidigoCfg        *config.ForbidigoSettings
+		funlenCfg           *config.FunlenSettings
+		gciCfg              *config.GciSettings
+		ginkgolinterCfg     *config.GinkgoLinterSettings
+		gocognitCfg         *config.GocognitSettings
+		goconstCfg          *config.GoConstSettings
+		gocriticCfg         *config.GoCriticSettings
+		gocycloCfg          *config.GoCycloSettings
+		godotCfg            *config.GodotSettings
+		godoxCfg            *config.GodoxSettings
+		gofmtCfg            *config.GoFmtSettings
+		gofumptCfg          *config.GofumptSettings
+		goheaderCfg         *config.GoHeaderSettings
+		goimportsCfg        *config.GoImportsSettings
+		golintCfg           *config.GoLintSettings
+		goMndCfg            *config.GoMndSettings
+		goModDirectivesCfg  *config.GoModDirectivesSettings
+		gomodguardCfg       *config.GoModGuardSettings
+		gosecCfg            *config.GoSecSettings
+		gosimpleCfg         *config.StaticCheckSettings
+		govetCfg            *config.GovetSettings
+		grouperCfg          *config.GrouperSettings
+		ifshortCfg          *config.IfshortSettings
+		importAsCfg         *config.ImportAsSettings
+		interfaceBloatCfg   *config.InterfaceBloatSettings
+		ireturnCfg          *config.IreturnSettings
+		lllCfg              *config.LllSettings
+		loggerCheckCfg      *config.LoggerCheckSettings
+		maintIdxCfg         *config.MaintIdxSettings
+		makezeroCfg         *config.MakezeroSettings
+		malignedCfg         *config.MalignedSettings
+		misspellCfg         *config.MisspellSettings
+		musttagCfg          *config.MustTagSettings
+		nakedretCfg         *config.NakedretSettings
+		nestifCfg           *config.NestifSettings
+		nilNilCfg           *config.NilNilSettings
+		nlreturnCfg         *config.NlreturnSettings
+		noLintLintCfg       *config.NoLintLintSettings
+		noNamedReturnsCfg   *config.NoNamedReturnsSettings
+		parallelTestCfg     *config.ParallelTestSettings
+		preallocCfg         *config.PreallocSettings
+		predeclaredCfg      *config.PredeclaredSettings
+		promlinterCfg       *config.PromlinterSettings
+		reassignCfg         *config.ReassignSettings
+		reviveCfg           *config.ReviveSettings
+		rowserrcheckCfg     *config.RowsErrCheckSettings
+		staticcheckCfg      *config.StaticCheckSettings
+		structcheckCfg      *config.StructCheckSettings
+		stylecheckCfg       *config.StaticCheckSettings
+		tagliatelleCfg      *config.TagliatelleSettings
+		tenvCfg             *config.TenvSettings
+		testpackageCfg      *config.TestpackageSettings
+		thelperCfg          *config.ThelperSettings
+		unparamCfg          *config.UnparamSettings
+		unusedCfg           *config.StaticCheckSettings
+		usestdlibvars       *config.UseStdlibVarsSettings
+		varcheckCfg         *config.VarCheckSettings
+		varnamelenCfg       *config.VarnamelenSettings
+		whitespaceCfg       *config.WhitespaceSettings
+		wrapcheckCfg        *config.WrapcheckSettings
+		wslCfg              *config.WSLSettings
+	)
 
 	if m.cfg != nil {
+		asasalintCfg = &m.cfg.LintersSettings.Asasalint
 		bidichkCfg = &m.cfg.LintersSettings.BiDiChk
 		cyclopCfg = &m.cfg.LintersSettings.Cyclop
-		errchkjsonCfg = &m.cfg.LintersSettings.ErrChkJSON
 		decorderCfg = &m.cfg.LintersSettings.Decorder
+		depGuardCfg = &m.cfg.LintersSettings.Depguard
+		dogsledCfg = &m.cfg.LintersSettings.Dogsled
+		duplCfg = &m.cfg.LintersSettings.Dupl
+		dupwordCfg = &m.cfg.LintersSettings.DupWord
+		errcheckCfg = &m.cfg.LintersSettings.Errcheck
+		errchkjsonCfg = &m.cfg.LintersSettings.ErrChkJSON
 		errorlintCfg = &m.cfg.LintersSettings.ErrorLint
 		exhaustiveCfg = &m.cfg.LintersSettings.Exhaustive
 		exhaustiveStructCfg = &m.cfg.LintersSettings.ExhaustiveStruct
 		exhaustructCfg = &m.cfg.LintersSettings.Exhaustruct
+		forbidigoCfg = &m.cfg.LintersSettings.Forbidigo
+		funlenCfg = &m.cfg.LintersSettings.Funlen
 		gciCfg = &m.cfg.LintersSettings.Gci
-		goModDirectivesCfg = &m.cfg.LintersSettings.GoModDirectives
+		ginkgolinterCfg = &m.cfg.LintersSettings.GinkgoLinter
+		gocognitCfg = &m.cfg.LintersSettings.Gocognit
+		goconstCfg = &m.cfg.LintersSettings.Goconst
+		gocriticCfg = &m.cfg.LintersSettings.Gocritic
+		gocycloCfg = &m.cfg.LintersSettings.Gocyclo
+		godotCfg = &m.cfg.LintersSettings.Godot
+		godoxCfg = &m.cfg.LintersSettings.Godox
+		gofmtCfg = &m.cfg.LintersSettings.Gofmt
+		gofumptCfg = &m.cfg.LintersSettings.Gofumpt
+		goheaderCfg = &m.cfg.LintersSettings.Goheader
+		goimportsCfg = &m.cfg.LintersSettings.Goimports
+		golintCfg = &m.cfg.LintersSettings.Golint
 		goMndCfg = &m.cfg.LintersSettings.Gomnd
+		goModDirectivesCfg = &m.cfg.LintersSettings.GoModDirectives
+		gomodguardCfg = &m.cfg.LintersSettings.Gomodguard
 		gosecCfg = &m.cfg.LintersSettings.Gosec
 		gosimpleCfg = &m.cfg.LintersSettings.Gosimple
 		govetCfg = &m.cfg.LintersSettings.Govet
 		grouperCfg = &m.cfg.LintersSettings.Grouper
 		ifshortCfg = &m.cfg.LintersSettings.Ifshort
 		importAsCfg = &m.cfg.LintersSettings.ImportAs
+		interfaceBloatCfg = &m.cfg.LintersSettings.InterfaceBloat
 		ireturnCfg = &m.cfg.LintersSettings.Ireturn
+		lllCfg = &m.cfg.LintersSettings.Lll
+		loggerCheckCfg = &m.cfg.LintersSettings.LoggerCheck
 		maintIdxCfg = &m.cfg.LintersSettings.MaintIdx
+		makezeroCfg = &m.cfg.LintersSettings.Makezero
+		malignedCfg = &m.cfg.LintersSettings.Maligned
+		misspellCfg = &m.cfg.LintersSettings.Misspell
+		musttagCfg = &m.cfg.LintersSettings.MustTag
+		nakedretCfg = &m.cfg.LintersSettings.Nakedret
+		nestifCfg = &m.cfg.LintersSettings.Nestif
 		nilNilCfg = &m.cfg.LintersSettings.NilNil
 		nlreturnCfg = &m.cfg.LintersSettings.Nlreturn
+		noLintLintCfg = &m.cfg.LintersSettings.NoLintLint
+		noNamedReturnsCfg = &m.cfg.LintersSettings.NoNamedReturns
+		preallocCfg = &m.cfg.LintersSettings.Prealloc
+		parallelTestCfg = &m.cfg.LintersSettings.ParallelTest
 		predeclaredCfg = &m.cfg.LintersSettings.Predeclared
+		promlinterCfg = &m.cfg.LintersSettings.Promlinter
+		reassignCfg = &m.cfg.LintersSettings.Reassign
 		reviveCfg = &m.cfg.LintersSettings.Revive
+		rowserrcheckCfg = &m.cfg.LintersSettings.RowsErrCheck
 		staticcheckCfg = &m.cfg.LintersSettings.Staticcheck
+		structcheckCfg = &m.cfg.LintersSettings.Structcheck
 		stylecheckCfg = &m.cfg.LintersSettings.Stylecheck
 		tagliatelleCfg = &m.cfg.LintersSettings.Tagliatelle
 		tenvCfg = &m.cfg.LintersSettings.Tenv
 		testpackageCfg = &m.cfg.LintersSettings.Testpackage
 		thelperCfg = &m.cfg.LintersSettings.Thelper
+		unparamCfg = &m.cfg.LintersSettings.Unparam
 		unusedCfg = &m.cfg.LintersSettings.Unused
+		varcheckCfg = &m.cfg.LintersSettings.Varcheck
 		varnamelenCfg = &m.cfg.LintersSettings.Varnamelen
+		whitespaceCfg = &m.cfg.LintersSettings.Whitespace
 		wrapcheckCfg = &m.cfg.LintersSettings.Wrapcheck
+		wslCfg = &m.cfg.LintersSettings.WSL
 
 		if govetCfg != nil {
 			govetCfg.Go = m.cfg.Run.Go
 		}
+
+		if gofumptCfg != nil && gofumptCfg.LangVersion == "" {
+			gofumptCfg.LangVersion = m.cfg.Run.Go
+		}
+
+		if staticcheckCfg != nil && staticcheckCfg.GoVersion == "" {
+			staticcheckCfg.GoVersion = m.cfg.Run.Go
+		}
+		if gosimpleCfg != nil && gosimpleCfg.GoVersion == "" {
+			gosimpleCfg.GoVersion = m.cfg.Run.Go
+		}
+		if stylecheckCfg != nil && stylecheckCfg.GoVersion != "" {
+			stylecheckCfg.GoVersion = m.cfg.Run.Go
+		}
+		if unusedCfg != nil && unusedCfg.GoVersion == "" {
+			unusedCfg.GoVersion = m.cfg.Run.Go
+		}
 	}
 
 	const megacheckName = "megacheck"
@@ -177,6 +281,12 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 	// The linters are sorted in the alphabetical order (case-insensitive).
 	// When a new linter is added the version in `WithSince(...)` must be the next minor version of golangci-lint.
 	lcs := []*linter.Config{
+		linter.NewConfig(golinters.NewAsasalint(asasalintCfg)).
+			WithSince("1.47.0").
+			WithPresets(linter.PresetBugs).
+			WithLoadForGoAnalysis().
+			WithURL("https://github.com/alingse/asasalint"),
+
 		linter.NewConfig(golinters.NewAsciicheck()).
 			WithSince("v1.26.0").
 			WithPresets(linter.PresetBugs, linter.PresetStyle).
@@ -191,8 +301,7 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithSince("v1.18.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetPerformance, linter.PresetBugs).
-			WithURL("https://github.com/timakin/bodyclose").
-			WithNoopFallback(m.cfg),
+			WithURL("https://github.com/timakin/bodyclose"),
 
 		linter.NewConfig(golinters.NewContainedCtx()).
 			WithSince("1.44.0").
@@ -203,8 +312,7 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithSince("v1.43.0").
 			WithPresets(linter.PresetBugs).
 			WithLoadForGoAnalysis().
-			WithURL("https://github.com/sylvia7788/contextcheck").
-			WithNoopFallback(m.cfg),
+			WithURL("https://github.com/kkHAIKE/contextcheck"),
 
 		linter.NewConfig(golinters.NewCyclop(cyclopCfg)).
 			WithSince("v1.37.0").
@@ -221,30 +329,37 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithSince("v1.0.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetUnused).
-			WithURL("https://github.com/remyoudompheng/go-misc/tree/master/deadcode"),
+			WithURL("https://github.com/remyoudompheng/go-misc/tree/master/deadcode").
+			Deprecated("The owner seems to have abandoned the linter.", "v1.49.0", "unused"),
 
-		linter.NewConfig(golinters.NewDepguard()).
+		linter.NewConfig(golinters.NewDepguard(depGuardCfg)).
 			WithSince("v1.4.0").
 			WithPresets(linter.PresetStyle, linter.PresetImport, linter.PresetModule).
 			WithURL("https://github.com/OpenPeeDeeP/depguard"),
 
-		linter.NewConfig(golinters.NewDogsled()).
+		linter.NewConfig(golinters.NewDogsled(dogsledCfg)).
 			WithSince("v1.19.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/alexkohler/dogsled"),
 
-		linter.NewConfig(golinters.NewDupl()).
+		linter.NewConfig(golinters.NewDupl(duplCfg)).
 			WithSince("v1.0.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/mibk/dupl"),
 
+		linter.NewConfig(golinters.NewDupWord(dupwordCfg)).
+			WithSince("1.50.0").
+			WithPresets(linter.PresetComment).
+			WithAutoFix().
+			WithURL("https://github.com/Abirdcfly/dupword"),
+
 		linter.NewConfig(golinters.NewDurationCheck()).
 			WithSince("v1.37.0").
 			WithPresets(linter.PresetBugs).
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/charithe/durationcheck"),
 
-		linter.NewConfig(golinters.NewErrcheck()).
+		linter.NewConfig(golinters.NewErrcheck(errcheckCfg)).
 			WithSince("v1.0.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetBugs, linter.PresetError).
@@ -299,7 +414,7 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/kyoh86/exportloopref"),
 
-		linter.NewConfig(golinters.NewForbidigo()).
+		linter.NewConfig(golinters.NewForbidigo(forbidigoCfg)).
 			WithSince("v1.34.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/ashanbrown/forbidigo"),
@@ -309,7 +424,7 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/gostaticanalysis/forcetypeassert"),
 
-		linter.NewConfig(golinters.NewFunlen()).
+		linter.NewConfig(golinters.NewFunlen(funlenCfg)).
 			WithSince("v1.18.0").
 			WithPresets(linter.PresetComplexity).
 			WithURL("https://github.com/ultraware/funlen"),
@@ -319,44 +434,55 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithPresets(linter.PresetFormatting, linter.PresetImport).
 			WithURL("https://github.com/daixiang0/gci"),
 
+		linter.NewConfig(golinters.NewGinkgoLinter(ginkgolinterCfg)).
+			WithSince("v1.51.0").
+			WithLoadForGoAnalysis().
+			WithPresets(linter.PresetStyle).
+			WithURL("https://github.com/nunnatsa/ginkgolinter"),
+
+		linter.NewConfig(golinters.NewGoCheckCompilerDirectives()).
+			WithSince("v1.51.0").
+			WithPresets(linter.PresetBugs).
+			WithURL("https://github.com/leighmcculloch/gocheckcompilerdirectives"),
+
 		linter.NewConfig(golinters.NewGochecknoglobals()).
 			WithSince("v1.12.0").
 			WithPresets(linter.PresetStyle).
+			WithLoadForGoAnalysis().
 			WithURL("https://github.com/leighmcculloch/gochecknoglobals"),
 
 		linter.NewConfig(golinters.NewGochecknoinits()).
 			WithSince("v1.12.0").
-			WithPresets(linter.PresetStyle).
-			WithURL("https://github.com/leighmcculloch/gochecknoinits"),
+			WithPresets(linter.PresetStyle),
 
-		linter.NewConfig(golinters.NewGocognit()).
+		linter.NewConfig(golinters.NewGocognit(gocognitCfg)).
 			WithSince("v1.20.0").
 			WithPresets(linter.PresetComplexity).
 			WithURL("https://github.com/uudashr/gocognit"),
 
-		linter.NewConfig(golinters.NewGoconst()).
+		linter.NewConfig(golinters.NewGoconst(goconstCfg)).
 			WithSince("v1.0.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/jgautheron/goconst"),
 
-		linter.NewConfig(golinters.NewGocritic()).
+		linter.NewConfig(golinters.NewGoCritic(gocriticCfg, m.cfg)).
 			WithSince("v1.12.0").
 			WithPresets(linter.PresetStyle, linter.PresetMetaLinter).
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/go-critic/go-critic"),
 
-		linter.NewConfig(golinters.NewGocyclo()).
+		linter.NewConfig(golinters.NewGocyclo(gocycloCfg)).
 			WithSince("v1.0.0").
 			WithPresets(linter.PresetComplexity).
 			WithURL("https://github.com/fzipp/gocyclo"),
 
-		linter.NewConfig(golinters.NewGodot()).
+		linter.NewConfig(golinters.NewGodot(godotCfg)).
 			WithSince("v1.25.0").
 			WithPresets(linter.PresetStyle, linter.PresetComment).
 			WithAutoFix().
 			WithURL("https://github.com/tetafro/godot"),
 
-		linter.NewConfig(golinters.NewGodox()).
+		linter.NewConfig(golinters.NewGodox(godoxCfg)).
 			WithSince("v1.19.0").
 			WithPresets(linter.PresetStyle, linter.PresetComment).
 			WithURL("https://github.com/matoous/godox"),
@@ -367,30 +493,30 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/Djarvur/go-err113"),
 
-		linter.NewConfig(golinters.NewGofmt()).
+		linter.NewConfig(golinters.NewGofmt(gofmtCfg)).
 			WithSince("v1.0.0").
 			WithPresets(linter.PresetFormatting).
 			WithAutoFix().
 			WithURL("https://golang.org/cmd/gofmt/"),
 
-		linter.NewConfig(golinters.NewGofumpt()).
+		linter.NewConfig(golinters.NewGofumpt(gofumptCfg)).
 			WithSince("v1.28.0").
 			WithPresets(linter.PresetFormatting).
 			WithAutoFix().
 			WithURL("https://github.com/mvdan/gofumpt"),
 
-		linter.NewConfig(golinters.NewGoHeader()).
+		linter.NewConfig(golinters.NewGoHeader(goheaderCfg)).
 			WithSince("v1.28.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/denis-tingaikin/go-header"),
 
-		linter.NewConfig(golinters.NewGoimports()).
+		linter.NewConfig(golinters.NewGoimports(goimportsCfg)).
 			WithSince("v1.20.0").
 			WithPresets(linter.PresetFormatting, linter.PresetImport).
 			WithAutoFix().
 			WithURL("https://godoc.org/golang.org/x/tools/cmd/goimports"),
 
-		linter.NewConfig(golinters.NewGolint()).
+		linter.NewConfig(golinters.NewGolint(golintCfg)).
 			WithSince("v1.0.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetStyle).
@@ -407,7 +533,7 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithPresets(linter.PresetStyle, linter.PresetModule).
 			WithURL("https://github.com/ldez/gomoddirectives"),
 
-		linter.NewConfig(golinters.NewGomodguard()).
+		linter.NewConfig(golinters.NewGomodguard(gomodguardCfg)).
 			WithSince("v1.25.0").
 			WithPresets(linter.PresetStyle, linter.PresetImport, linter.PresetModule).
 			WithURL("https://github.com/ryancurrah/gomodguard"),
@@ -446,7 +572,8 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 		linter.NewConfig(golinters.NewIfshort(ifshortCfg)).
 			WithSince("v1.36.0").
 			WithPresets(linter.PresetStyle).
-			WithURL("https://github.com/esimonov/ifshort"),
+			WithURL("https://github.com/esimonov/ifshort").
+			Deprecated("The repository of the linter has been deprecated by the owner.", "v1.48.0", ""),
 
 		linter.NewConfig(golinters.NewImportAs(importAsCfg)).
 			WithSince("v1.38.0").
@@ -459,13 +586,17 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithPresets(linter.PresetUnused).
 			WithURL("https://github.com/gordonklaus/ineffassign"),
 
+		linter.NewConfig(golinters.NewInterfaceBloat(interfaceBloatCfg)).
+			WithSince("v1.49.0").
+			WithPresets(linter.PresetStyle).
+			WithURL("https://github.com/sashamelentyev/interfacebloat"),
+
 		linter.NewConfig(golinters.NewInterfacer()).
 			WithSince("v1.0.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/mvdan/interfacer").
-			Deprecated("The repository of the linter has been archived by the owner.", "v1.38.0", "").
-			WithNoopFallback(m.cfg),
+			Deprecated("The repository of the linter has been archived by the owner.", "v1.38.0", ""),
 
 		linter.NewConfig(golinters.NewIreturn(ireturnCfg)).
 			WithSince("v1.43.0").
@@ -473,40 +604,53 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/butuzov/ireturn"),
 
-		linter.NewConfig(golinters.NewLLL()).
+		linter.NewConfig(golinters.NewLLL(lllCfg)).
 			WithSince("v1.8.0").
 			WithPresets(linter.PresetStyle),
 
+		linter.NewConfig(golinters.NewLoggerCheck(loggerCheckCfg)).
+			WithSince("v1.49.0").
+			WithLoadForGoAnalysis().
+			WithPresets(linter.PresetStyle, linter.PresetBugs).
+			WithAlternativeNames("logrlint").
+			WithURL("https://github.com/timonwong/loggercheck"),
+
 		linter.NewConfig(golinters.NewMaintIdx(maintIdxCfg)).
 			WithSince("v1.44.0").
 			WithPresets(linter.PresetComplexity).
 			WithURL("https://github.com/yagipy/maintidx"),
 
-		linter.NewConfig(golinters.NewMakezero()).
+		linter.NewConfig(golinters.NewMakezero(makezeroCfg)).
 			WithSince("v1.34.0").
 			WithPresets(linter.PresetStyle, linter.PresetBugs).
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/ashanbrown/makezero"),
 
-		linter.NewConfig(golinters.NewMaligned()).
+		linter.NewConfig(golinters.NewMaligned(malignedCfg)).
 			WithSince("v1.0.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetPerformance).
 			WithURL("https://github.com/mdempsky/maligned").
 			Deprecated("The repository of the linter has been archived by the owner.", "v1.38.0", "govet 'fieldalignment'"),
 
-		linter.NewConfig(golinters.NewMisspell()).
+		linter.NewConfig(golinters.NewMisspell(misspellCfg)).
 			WithSince("v1.8.0").
 			WithPresets(linter.PresetStyle, linter.PresetComment).
 			WithAutoFix().
 			WithURL("https://github.com/client9/misspell"),
 
-		linter.NewConfig(golinters.NewNakedret()).
+		linter.NewConfig(golinters.NewMustTag(musttagCfg)).
+			WithSince("v1.51.0").
+			WithLoadForGoAnalysis().
+			WithPresets(linter.PresetStyle, linter.PresetBugs).
+			WithURL("https://github.com/junk1tm/musttag"),
+
+		linter.NewConfig(golinters.NewNakedret(nakedretCfg)).
 			WithSince("v1.19.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/alexkohler/nakedret"),
 
-		linter.NewConfig(golinters.NewNestif()).
+		linter.NewConfig(golinters.NewNestif(nestifCfg)).
 			WithSince("v1.25.0").
 			WithPresets(linter.PresetComplexity).
 			WithURL("https://github.com/nakabonne/nestif"),
@@ -515,8 +659,7 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithSince("v1.38.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetBugs).
-			WithURL("https://github.com/gostaticanalysis/nilerr").
-			WithNoopFallback(m.cfg),
+			WithURL("https://github.com/gostaticanalysis/nilerr"),
 
 		linter.NewConfig(golinters.NewNilNil(nilNilCfg)).
 			WithSince("v1.43.0").
@@ -533,25 +676,32 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithSince("v1.28.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetPerformance, linter.PresetBugs).
-			WithURL("https://github.com/sonatard/noctx").
-			WithNoopFallback(m.cfg),
+			WithURL("https://github.com/sonatard/noctx"),
 
-		linter.NewConfig(golinters.NewNoNamedReturns()).
+		linter.NewConfig(golinters.NewNoNamedReturns(noNamedReturnsCfg)).
 			WithSince("v1.46.0").
+			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/firefart/nonamedreturns"),
 
+		linter.NewConfig(golinters.NewNoSnakeCase()).
+			WithSince("v1.47.0").
+			WithPresets(linter.PresetStyle).
+			WithURL("https://github.com/sivchari/nosnakecase").
+			Deprecated("The repository of the linter has been deprecated by the owner.", "v1.48.1", "revive(var-naming)"),
+
 		linter.NewConfig(golinters.NewNoSprintfHostPort()).
 			WithSince("v1.46.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/stbenjam/no-sprintf-host-port"),
 
-		linter.NewConfig(golinters.NewParallelTest()).
+		linter.NewConfig(golinters.NewParallelTest(parallelTestCfg)).
 			WithSince("v1.33.0").
+			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetStyle, linter.PresetTest).
 			WithURL("https://github.com/kunwardeep/paralleltest"),
 
-		linter.NewConfig(golinters.NewPrealloc()).
+		linter.NewConfig(golinters.NewPreAlloc(preallocCfg)).
 			WithSince("v1.19.0").
 			WithPresets(linter.PresetPerformance).
 			WithURL("https://github.com/alexkohler/prealloc"),
@@ -561,18 +711,24 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/nishanths/predeclared"),
 
-		linter.NewConfig(golinters.NewPromlinter()).
+		linter.NewConfig(golinters.NewPromlinter(promlinterCfg)).
 			WithSince("v1.40.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/yeya24/promlinter"),
 
+		linter.NewConfig(golinters.NewReassign(reassignCfg)).
+			WithSince("1.49.0").
+			WithPresets(linter.PresetBugs).
+			WithLoadForGoAnalysis().
+			WithURL("https://github.com/curioswitch/go-reassign"),
+
 		linter.NewConfig(golinters.NewRevive(reviveCfg)).
 			WithSince("v1.37.0").
 			WithPresets(linter.PresetStyle, linter.PresetMetaLinter).
 			ConsiderSlow().
 			WithURL("https://github.com/mgechev/revive"),
 
-		linter.NewConfig(golinters.NewRowsErrCheck()).
+		linter.NewConfig(golinters.NewRowsErrCheck(rowserrcheckCfg)).
 			WithSince("v1.23.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetBugs, linter.PresetSQL).
@@ -589,8 +745,7 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithSince("v1.28.0").
 			WithPresets(linter.PresetBugs, linter.PresetSQL).
 			WithLoadForGoAnalysis().
-			WithURL("https://github.com/ryanrolds/sqlclosecheck").
-			WithNoopFallback(m.cfg),
+			WithURL("https://github.com/ryanrolds/sqlclosecheck"),
 
 		linter.NewConfig(golinters.NewStaticcheck(staticcheckCfg)).
 			WithSince("v1.0.0").
@@ -599,11 +754,12 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithAlternativeNames(megacheckName).
 			WithURL("https://staticcheck.io/"),
 
-		linter.NewConfig(golinters.NewStructcheck()).
+		linter.NewConfig(golinters.NewStructcheck(structcheckCfg)).
 			WithSince("v1.0.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetUnused).
 			WithURL("https://github.com/opennota/check").
+			Deprecated("The owner seems to have abandoned the linter.", "v1.49.0", "unused").
 			WithNoopFallback(m.cfg),
 
 		linter.NewConfig(golinters.NewStylecheck(stylecheckCfg)).
@@ -623,6 +779,11 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/sivchari/tenv"),
 
+		linter.NewConfig(golinters.NewTestableexamples()).
+			WithSince("v1.50.0").
+			WithPresets(linter.PresetTest).
+			WithURL("https://github.com/maratori/testableexamples"),
+
 		linter.NewConfig(golinters.NewTestpackage(testpackageCfg)).
 			WithSince("v1.25.0").
 			WithPresets(linter.PresetStyle, linter.PresetTest).
@@ -638,8 +799,7 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithSince("v1.32.0").
 			WithPresets(linter.PresetStyle, linter.PresetTest).
 			WithLoadForGoAnalysis().
-			WithURL("https://github.com/moricho/tparallel").
-			WithNoopFallback(m.cfg),
+			WithURL("https://github.com/moricho/tparallel"),
 
 		linter.NewConfig(golinters.NewTypecheck()).
 			WithSince("v1.3.0").
@@ -653,12 +813,11 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/mdempsky/unconvert"),
 
-		linter.NewConfig(golinters.NewUnparam()).
+		linter.NewConfig(golinters.NewUnparam(unparamCfg)).
 			WithSince("v1.9.0").
 			WithPresets(linter.PresetUnused).
 			WithLoadForGoAnalysis().
-			WithURL("https://github.com/mvdan/unparam").
-			WithNoopFallback(m.cfg),
+			WithURL("https://github.com/mvdan/unparam"),
 
 		linter.NewConfig(golinters.NewUnused(unusedCfg)).
 			WithSince("v1.20.0").
@@ -669,11 +828,17 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithChangeTypes().
 			WithURL("https://github.com/dominikh/go-tools/tree/master/unused"),
 
-		linter.NewConfig(golinters.NewVarcheck()).
+		linter.NewConfig(golinters.NewUseStdlibVars(usestdlibvars)).
+			WithSince("v1.48.0").
+			WithPresets(linter.PresetStyle).
+			WithURL("https://github.com/sashamelentyev/usestdlibvars"),
+
+		linter.NewConfig(golinters.NewVarcheck(varcheckCfg)).
 			WithSince("v1.0.0").
 			WithLoadForGoAnalysis().
 			WithPresets(linter.PresetUnused).
-			WithURL("https://github.com/opennota/check"),
+			WithURL("https://github.com/opennota/check").
+			Deprecated("The owner seems to have abandoned the linter.", "v1.49.0", "unused"),
 
 		linter.NewConfig(golinters.NewVarnamelen(varnamelenCfg)).
 			WithSince("v1.43.0").
@@ -688,7 +853,7 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithURL("https://github.com/sanposhiho/wastedassign").
 			WithNoopFallback(m.cfg),
 
-		linter.NewConfig(golinters.NewWhitespace()).
+		linter.NewConfig(golinters.NewWhitespace(whitespaceCfg)).
 			WithSince("v1.19.0").
 			WithPresets(linter.PresetStyle).
 			WithAutoFix().
@@ -700,13 +865,13 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 			WithLoadForGoAnalysis().
 			WithURL("https://github.com/tomarrell/wrapcheck"),
 
-		linter.NewConfig(golinters.NewWSL()).
+		linter.NewConfig(golinters.NewWSL(wslCfg)).
 			WithSince("v1.20.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/bombsimon/wsl"),
 
 		// nolintlint must be last because it looks at the results of all the previous linters for unused nolint directives
-		linter.NewConfig(golinters.NewNoLintLint()).
+		linter.NewConfig(golinters.NewNoLintLint(noLintLintCfg)).
 			WithSince("v1.26.0").
 			WithPresets(linter.PresetStyle).
 			WithURL("https://github.com/golangci/golangci-lint/blob/master/pkg/golinters/nolintlint/README.md"),
@@ -714,14 +879,11 @@ func (m Manager) GetAllSupportedLinterConfigs() []*linter.Config {
 
 	enabledByDefault := map[string]bool{
 		golinters.NewGovet(nil).Name():                  true,
-		golinters.NewErrcheck().Name():                  true,
+		golinters.NewErrcheck(errcheckCfg).Name():       true,
 		golinters.NewStaticcheck(staticcheckCfg).Name(): true,
 		golinters.NewUnused(unusedCfg).Name():           true,
 		golinters.NewGosimple(gosimpleCfg).Name():       true,
-		golinters.NewStructcheck().Name():               true,
-		golinters.NewVarcheck().Name():                  true,
 		golinters.NewIneffassign().Name():               true,
-		golinters.NewDeadcode().Name():                  true,
 		golinters.NewTypecheck().Name():                 true,
 	}
 	return enableLinterConfigs(lcs, func(lc *linter.Config) bool {
@@ -753,6 +915,10 @@ func linterConfigsToMap(lcs []*linter.Config) map[string]*linter.Config {
 func (m Manager) GetAllLinterConfigsForPreset(p string) []*linter.Config {
 	var ret []*linter.Config
 	for _, lc := range m.GetAllSupportedLinterConfigs() {
+		if lc.IsDeprecated() {
+			continue
+		}
+
 		for _, ip := range lc.InPresets {
 			if p == ip {
 				ret = append(ret, lc)
